@@ -27,7 +27,7 @@ void UpdateLandscapingLimits();
 bool CheckCompanyHasMoney(CommandCost &cost);
 void SubtractMoneyFromCompany(const CommandCost& cost);
 void SubtractMoneyFromCompanyFract(CompanyID company, const CommandCost& cost);
-CommandCost CheckOwnership(Owner owner, TileIndex tile = 0);
+CommandCost CheckOwnership(Owner owner, TileIndex tile = 0U);
 CommandCost CheckTileOwnership(TileIndex tile);
 
 extern CompanyID _local_company;
@@ -56,5 +56,6 @@ static inline bool IsInteractiveCompany(CompanyID company)
 }
 
 int CompanyServiceInterval(const Company *c, VehicleType type);
+CompanyID GetFirstPlayableCompanyID();
 
 #endif /* COMPANY_FUNC_H */
