@@ -12,10 +12,10 @@
 
 #if defined(ARM) || defined(__arm__) || defined(__alpha__)
 	/** The architecture requires aligned access. */
-	#define OTTD_ALIGNMENT 1
+#	define OTTD_ALIGNMENT 1
 #else
 	/** The architecture does not require aligned access. */
-	#define OTTD_ALIGNMENT 0
+#	define OTTD_ALIGNMENT 0
 #endif
 
 /** Little endian builds use this for TTD_ENDIAN. */
@@ -23,30 +23,8 @@
 /** Big endian builds use this for TTD_ENDIAN. */
 #define TTD_BIG_ENDIAN 1
 
-/* Windows has always LITTLE_ENDIAN */
-#if defined(_WIN32) || defined(__OS2__) || defined(__HAIKU__)
-#	define TTD_ENDIAN TTD_LITTLE_ENDIAN
-#elif defined(OSX)
-#	include <sys/types.h>
-#	if __DARWIN_BYTE_ORDER == __DARWIN_LITTLE_ENDIAN
-#		define TTD_ENDIAN TTD_LITTLE_ENDIAN
-#	else
-#		define TTD_ENDIAN TTD_BIG_ENDIAN
-#	endif
-#elif defined(__OpenBSD__)
-#	include <endian.h>
-#	if BYTE_ORDER == LITTLE_ENDIAN
-#		define TTD_ENDIAN TTD_LITTLE_ENDIAN
-#	else
-#		define TTD_ENDIAN TTD_BIG_ENDIAN
-#	endif
-#elif !defined(TESTING)
-#	include <sys/param.h>
-#	if __BYTE_ORDER == __LITTLE_ENDIAN
-#		define TTD_ENDIAN TTD_LITTLE_ENDIAN
-#	else
-#		define TTD_ENDIAN TTD_BIG_ENDIAN
-#	endif
-#endif /* _WIN32 || __OS2__ */
+#if !defined(TTD_ENDIAN)
+#	error "TTD_ENDIAN is not defined; please set it to either TTD_LITTLE_ENDIAN or TTD_BIG_ENDIAN"
+#endif /* !TTD_ENDIAN */
 
 #endif /* ENDIAN_TYPE_HPP */
