@@ -22,8 +22,8 @@
 
 /**
  * Overflow safe template for integers, i.e. integers that will never overflow
- * you multiply the maximum value with 2, or add 2, or subtract something from
- * the minimum value, etc.
+ * when you multiply the maximum value with 2, or add 2, or subtract something
+ * from the minimum value, etc.
  * @param T     the type these integers are stored with.
  */
 template <class T>
@@ -39,9 +39,10 @@ public:
 	constexpr OverflowSafeInt() : m_value(0) { }
 
 	constexpr OverflowSafeInt(const OverflowSafeInt& other) : m_value(other.m_value) { }
-	constexpr OverflowSafeInt(const int64 int_) : m_value(int_) { }
+	constexpr OverflowSafeInt(const T int_) : m_value(int_) { }
 
 	inline constexpr OverflowSafeInt& operator = (const OverflowSafeInt& other) { this->m_value = other.m_value; return *this; }
+	inline constexpr OverflowSafeInt& operator = (T other) { this->m_value = other; return *this; }
 
 	inline constexpr OverflowSafeInt operator - () const { return OverflowSafeInt(this->m_value == T_MIN ? T_MAX : -this->m_value); }
 
@@ -174,7 +175,10 @@ public:
 	inline constexpr bool operator <  (const int other) const { return !(*this >= other); }
 	inline constexpr bool operator <= (const int other) const { return !(*this > other); }
 
-	inline constexpr operator int64 () const { return this->m_value; }
+	inline constexpr operator T () const { return this->m_value; }
+
+	static inline constexpr OverflowSafeInt<T> max() { return T_MAX; }
+	static inline constexpr OverflowSafeInt<T> min() { return T_MIN; }
 };
 
 
