@@ -46,7 +46,7 @@ extern int _debug_sprite_level;
 extern int _debug_oldloader_level;
 extern int _debug_npf_level;
 extern int _debug_yapf_level;
-extern int _debug_freetype_level;
+extern int _debug_fontcache_level;
 extern int _debug_script_level;
 extern int _debug_sl_level;
 extern int _debug_gamelog_level;
@@ -57,7 +57,7 @@ extern int _debug_random_level;
 #endif
 
 char *DumpDebugFacilityNames(char *buf, char *last);
-void SetDebugString(const char *s);
+void SetDebugString(const char *s, void (*error_func)(const char *));
 const char *GetDebugString();
 
 /* Shorter form for passing filename and linenumber */
