@@ -27,8 +27,6 @@ INSTANTIATE_POOL_METHODS(Depot)
  */
 Depot::~Depot()
 {
-	free(this->name);
-
 	if (CleaningPool()) return;
 
 	if (!IsDepotTile(this->xy) || GetDepotIndex(this->xy) != this->index) {
@@ -43,9 +41,9 @@ Depot::~Depot()
 	RemoveOrderFromAllVehicles(OT_GOTO_DEPOT, this->index);
 
 	/* Delete the depot-window */
-	DeleteWindowById(WC_VEHICLE_DEPOT, this->xy);
+	CloseWindowById(WC_VEHICLE_DEPOT, this->xy);
 
 	/* Delete the depot list */
 	VehicleType vt = GetDepotVehicleType(this->xy);
-	DeleteWindowById(GetWindowClassForVehicleType(vt), VehicleListIdentifier(VL_DEPOT_LIST, vt, GetTileOwner(this->xy), this->index).Pack());
+	CloseWindowById(GetWindowClassForVehicleType(vt), VehicleListIdentifier(VL_DEPOT_LIST, vt, GetTileOwner(this->xy), this->index).Pack());
 }
