@@ -12,10 +12,13 @@
 
 #include "music_driver.hpp"
 
+/* For BMidiSynthFile */
+#include <MidiSynthFile.h>
+
 /** The midi player for BeOS. */
 class MusicDriver_BeMidi : public MusicDriver {
 public:
-	const char *Start(const char * const *param) override;
+	const char *Start(const StringList &param) override;
 
 	void Stop() override;
 
@@ -27,6 +30,11 @@ public:
 
 	void SetVolume(byte vol) override;
 	const char *GetName() const override { return "bemidi"; }
+
+private:
+	BMidiSynthFile *midi_synth_file = nullptr;
+	double current_volume = 1.0;
+	bool just_started = false;
 };
 
 /** Factory for the BeOS midi player. */
