@@ -22,7 +22,7 @@ private:
 	void DoStop();
 
 public:
-	const char *Start(const char * const *param) override;
+	const char *Start(const StringList &param) override;
 
 	void Stop() override;
 
