@@ -15,7 +15,7 @@
 /** The music player that does nothing. */
 class MusicDriver_Null : public MusicDriver {
 public:
-	const char *Start(const char * const *param) override { return nullptr; }
+	const char *Start(const StringList &param) override { return nullptr; }
 
 	void Stop() override { }
 
