@@ -52,7 +52,7 @@ TCPServerConnecter::TCPServerConnecter(const std::string &connection_string, uin
 			break;
 
 		case SERVER_ADDRESS_INVITE_CODE:
-			this->status = Status::CONNECTING;
+			this->status = Status::Connecting;
 			_network_coordinator_client.ConnectToServer(this->server_address.connection_string, this);
 			break;
 
@@ -254,14 +254,14 @@ void TCPConnecter::Resolve()
 
 	if (error != 0) {
 		Debug(net, 0, "Failed to resolve DNS for {}", this->connection_string);
-		this->status = Status::FAILURE;
+		this->status = Status::Failure;
 		return;
 	}
 
 	this->ai = ai;
 	this->OnResolved(ai);
 
-	this->status = Status::CONNECTING;
+	this->status = Status::Connecting;
 }
 
 /**
@@ -281,11 +281,11 @@ bool TCPConnecter::CheckActivity()
 	if (this->killed) return true;
 
 	switch (this->status) {
-		case Status::INIT:
+		case Status::Init:
 			/* Start the thread delayed, so the vtable is loaded. This allows classes
 			 * to overload functions used by Resolve() (in case threading is disabled). */
 			if (StartNewThread(&this->resolve_thread, "ottd:resolve", &TCPConnecter::ResolveThunk, this)) {
-				this->status = Status::RESOLVING;
+				this->status = Status::Resolving;
 				return false;
 			}
 
@@ -296,18 +296,18 @@ bool TCPConnecter::CheckActivity()
 			 * connection. The rest of this function handles exactly that. */
 			break;
 
-		case Status::RESOLVING:
+		case Status::Resolving:
 			/* Wait till Resolve() comes back with an answer (in case it runs threaded). */
 			return false;
 
-		case Status::FAILURE:
+		case Status::Failure:
 			/* Ensure the OnFailure() is called from the game-thread instead of the
 			 * resolve-thread, as otherwise we can get into some threading issues. */
 			this->OnFailure();
 			return true;
 
-		case Status::CONNECTING:
-		case Status::CONNECTED:
+		case Status::Connecting:
+		case Status::Connected:
 			break;
 	}
 
@@ -403,7 +403,7 @@ bool TCPConnecter::CheckActivity()
 	}
 
 	this->OnConnect(connected_socket);
-	this->status = Status::CONNECTED;
+	this->status = Status::Connected;
 	return true;
 }
 
@@ -422,11 +422,11 @@ bool TCPServerConnecter::CheckActivity()
 		case SERVER_ADDRESS_INVITE_CODE:
 			/* Check if a result has come in. */
 			switch (this->status) {
-				case Status::FAILURE:
+				case Status::Failure:
 					this->OnFailure();
 					return true;
 
-				case Status::CONNECTED:
+				case Status::Connected:
 					this->OnConnect(this->socket);
 					return true;
 
@@ -451,7 +451,7 @@ void TCPServerConnecter::SetConnected(SOCKET sock)
 	assert(sock != INVALID_SOCKET);
 
 	this->socket = sock;
-	this->status = Status::CONNECTED;
+	this->status = Status::Connected;
 }
 
 /**
@@ -459,7 +459,7 @@ void TCPServerConnecter::SetConnected(SOCKET sock)
  */
 void TCPServerConnecter::SetFailure()
 {
-	this->status = Status::FAILURE;
+	this->status = Status::Failure;
 }
 
 /**
