@@ -279,6 +279,9 @@ enum CallbackID {
 
 	/** Called to spawn visual effects for vehicles. */
 	CBID_VEHICLE_SPAWN_VISUAL_EFFECT     = 0x160, // 15 bit callback
+
+	/** Called to determine the engine name to show. */
+	CBID_VEHICLE_NAME                    = 0x161, // 15 bit callback
 };
 
 /**
@@ -294,6 +297,7 @@ enum VehicleCallbackMask {
 	CBM_VEHICLE_CARGO_SUFFIX   = 5, ///< Show suffix after cargo name
 	CBM_VEHICLE_COLOUR_REMAP   = 6, ///< Change colour mapping of vehicle
 	CBM_VEHICLE_SOUND_EFFECT   = 7, ///< Vehicle uses custom sound effects
+	CBM_VEHICLE_NAME           = 8, ///< Engine name
 };
 
 /**
