@@ -10,8 +10,6 @@
 #ifndef STRING_UNISCRIBE_H
 #define STRING_UNISCRIBE_H
 
-#if defined(WITH_UNISCRIBE)
-
 #include "../../gfx_layout.h"
 #include "../../string_base.h"
 #include <vector>
@@ -85,6 +83,4 @@ public:
 	size_t Prev(IterType what) override;
 };
 
-#endif /* defined(WITH_UNISCRIBE) */
-
 #endif /* STRING_UNISCRIBE_H */
