@@ -11,6 +11,7 @@
 #include "../string_func.h"
 #include "../strings_func.h"
 #include "saveload_internal.h"
+#include <sstream>
 
 #include "table/strings.h"
 
@@ -56,18 +57,17 @@ char *_old_name_array = nullptr;
  * @param id the StringID of the custom name to clone.
  * @return the clones custom name.
  */
-char *CopyFromOldName(StringID id)
+std::string CopyFromOldName(StringID id)
 {
 	/* Is this name an (old) custom name? */
-	if (GetStringTab(id) != TEXT_TAB_OLD_CUSTOM) return nullptr;
+	if (GetStringTab(id) != TEXT_TAB_OLD_CUSTOM) return std::string();
 
 	if (IsSavegameVersionBefore(SLV_37)) {
-		/* Allow for expansion when converted to UTF-8. */
-		char tmp[LEN_OLD_STRINGS * MAX_CHAR_LENGTH];
 		uint offs = _savegame_type == SGT_TTO ? LEN_OLD_STRINGS_TTO * GB(id, 0, 8) : LEN_OLD_STRINGS * GB(id, 0, 9);
 		const char *strfrom = &_old_name_array[offs];
-		char *strto = tmp;
 
+		std::ostringstream tmp;
+		std::ostreambuf_iterator<char> strto(tmp);
 		for (; *strfrom != '\0'; strfrom++) {
 			WChar c = (byte)*strfrom;
 
@@ -84,19 +84,13 @@ char *CopyFromOldName(StringID id)
 				default: break;
 			}
 
-			/* Check character will fit into our buffer. */
-			if (strto + Utf8CharLen(c) > lastof(tmp)) break;
-
-			strto += Utf8Encode(strto, c);
+			Utf8Encode(strto, c);
 		}
 
-		/* Terminate the new string and copy it back to the name array */
-		*strto = '\0';
-
-		return stredup(tmp);
+		return tmp.str();
 	} else {
 		/* Name will already be in UTF-8. */
-		return stredup(&_old_name_array[LEN_OLD_STRINGS * GB(id, 0, 9)]);
+		return std::string(&_old_name_array[LEN_OLD_STRINGS * GB(id, 0, 9)]);
 	}
 }
 
@@ -119,24 +113,27 @@ void InitializeOldNames()
 	_old_name_array = CallocT<char>(NUM_OLD_STRINGS * LEN_OLD_STRINGS); // 200 * 24 would be enough for TTO savegames
 }
 
-/**
- * Load the NAME chunk.
- */
-static void Load_NAME()
-{
-	int index;
+struct NAMEChunkHandler : ChunkHandler {
+	NAMEChunkHandler() : ChunkHandler('NAME', CH_READONLY) {}
 
-	while ((index = SlIterateArray()) != -1) {
-		if (index >= NUM_OLD_STRINGS) SlErrorCorrupt("Invalid old name index");
-		if (SlGetFieldLength() > (uint)LEN_OLD_STRINGS) SlErrorCorrupt("Invalid old name length");
+	void Load() const override
+	{
+		int index;
 
-		SlArray(&_old_name_array[LEN_OLD_STRINGS * index], SlGetFieldLength(), SLE_UINT8);
-		/* Make sure the old name is null terminated */
-		_old_name_array[LEN_OLD_STRINGS * index + LEN_OLD_STRINGS - 1] = '\0';
+		while ((index = SlIterateArray()) != -1) {
+			if (index >= NUM_OLD_STRINGS) SlErrorCorrupt("Invalid old name index");
+			if (SlGetFieldLength() > (uint)LEN_OLD_STRINGS) SlErrorCorrupt("Invalid old name length");
+
+			SlCopy(&_old_name_array[LEN_OLD_STRINGS * index], SlGetFieldLength(), SLE_UINT8);
+			/* Make sure the old name is null terminated */
+			_old_name_array[LEN_OLD_STRINGS * index + LEN_OLD_STRINGS - 1] = '\0';
+		}
 	}
-}
-
-/** Chunk handlers related to strings. */
-extern const ChunkHandler _name_chunk_handlers[] = {
-	{ 'NAME', nullptr, Load_NAME, nullptr, nullptr, CH_ARRAY | CH_LAST},
 };
+
+static const NAMEChunkHandler NAME;
+static const ChunkHandlerRef name_chunk_handlers[] = {
+	NAME,
+};
+
+extern const ChunkHandlerTable _name_chunk_handlers(name_chunk_handlers);
