@@ -12,17 +12,18 @@
 #include "../../command_type.h"
 #include "../../settings_type.h"
 #include "../../network/network.h"
+#include "../../misc_cmd.h"
 
 #include "../../safeguards.h"
 
 /* static */ bool ScriptGame::Pause()
 {
-	return ScriptObject::DoCommand(0, PM_PAUSED_GAME_SCRIPT, 1, CMD_PAUSE);
+	return ScriptObject::Command<CMD_PAUSE>::Do(PM_PAUSED_GAME_SCRIPT, true);
 }
 
 /* static */ bool ScriptGame::Unpause()
 {
-	return ScriptObject::DoCommand(0, PM_PAUSED_GAME_SCRIPT, 0, CMD_PAUSE);
+	return ScriptObject::Command<CMD_PAUSE>::Do(PM_PAUSED_GAME_SCRIPT, false);
 }
 
 /* static */ bool ScriptGame::IsPaused()
