@@ -16,9 +16,8 @@ typedef uint16 StoryPageElementID; ///< ID of a story page element
 typedef uint16 StoryPageID; ///< ID of a story page
 struct StoryPageElement;
 struct StoryPage;
+enum StoryPageElementType : byte;
 
-extern StoryPageElementID _new_story_page_element_id;
-extern StoryPageID _new_story_page_id;
 static const StoryPageElementID INVALID_STORY_PAGE_ELEMENT = 0xFFFF; ///< Constant representing a non-existing story page element.
 static const StoryPageID INVALID_STORY_PAGE = 0xFFFF; ///< Constant representing a non-existing story page.
 
