@@ -15,10 +15,10 @@
 #include <string>
 
 /** A non-breaking space. */
-#define NBSP "\xC2\xA0"
+#define NBSP u8"\u00a0"
 
 /** A left-to-right marker, marks the next character as left-to-right. */
-#define LRM "\xE2\x80\x8E"
+#define LRM u8"\u200e"
 
 /**
  * Valid filter types for IsValidChar.
@@ -27,12 +27,13 @@ enum CharSetFilter {
 	CS_ALPHANUMERAL,      ///< Both numeric and alphabetic and spaces and stuff
 	CS_NUMERAL,           ///< Only numeric ones
 	CS_NUMERAL_SPACE,     ///< Only numbers and spaces
+	CS_NUMERAL_SIGNED,    ///< Only numbers and '-' for negative values
 	CS_ALPHA,             ///< Only alphabetic values
 	CS_HEXADECIMAL,       ///< Only hexadecimal characters
 };
 
 /** Type for wide characters, i.e. non-UTF8 encoded unicode characters. */
-typedef uint32 WChar;
+typedef char32_t WChar;
 
 /* The following are directional formatting codes used to get the LTR and RTL strings right:
  * http://www.unicode.org/unicode/reports/tr9/#Directional_Formatting_Codes */
