@@ -1943,7 +1943,7 @@ static const char * const _name_romanian_real[] = {
 	u8"Bac\u0103u",
 	"Baia Mare",
 	u8"B\u0103ile Herculane",
-	u8"B\u0103ilesti",
+	u8"B\u0103ile\u0219ti",
 	u8"B\u00e2rlad",
 	"Bicaz",
 	u8"Bistri\u021ba",
@@ -1951,11 +1951,11 @@ static const char * const _name_romanian_real[] = {
 	"Borsec",
 	u8"Boto\u0219ani",
 	u8"Br\u0103ila",
-	u8"Bra\u021bov",
+	u8"Bra\u0219ov",
 	u8"Bucure\u0219ti",
 	"Buftea",
 	u8"Buz\u0103u",
-	u8"C\u0103l\u0103rasi",
+	u8"C\u0103l\u0103ra\u0219i",
 	u8"Caransebe\u0219",
 	u8"Cernavod\u0103",
 	"Cluj-Napoca",
@@ -1966,12 +1966,12 @@ static const char * const _name_romanian_real[] = {
 	"Deva",
 	"Dorohoi",
 	"Drobeta-Turnu Severin",
-	u8"Dr\u0103g\u0103sani",
-	u8"F\u0103g\u0103ras",
+	u8"Dr\u0103g\u0103\u0219ani",
+	u8"F\u0103g\u0103ra\u0219",
 	u8"F\u0103lticeni",
 	u8"Fete\u0219ti",
 	u8"Foc\u0219ani",
-	u8"Gala\u0219i",
+	u8"Gala\u021bi",
 	"Gheorgheni",
 	"Giurgiu",
 	u8"H\u00e2r\u0219ova",
@@ -2015,10 +2015,10 @@ static const char * const _name_romanian_real[] = {
 	"Sovata",
 	"Suceava",
 	"Sulina",
-	u8"T\u0103nd\u0103rei",
-	u8"T\u00e2rgoviste",
+	u8"\u021a\u0103nd\u0103rei",
+	u8"T\u00e2rgovi\u0219te",
 	u8"T\u00e2rgu Jiu",
-	u8"T\u00e2rgu Mures",
+	u8"T\u00e2rgu Mure\u0219",
 	"Tecuci",
 	u8"Timi\u0219oara",
 	"Tulcea",
