@@ -1,5 +1,3 @@
-/* $Id$ */
-
 /*
  * This file is part of OpenTTD.
  * OpenTTD is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 2.
@@ -17,7 +15,7 @@
 char *GenerateTownNameString(char *buf, const char *last, size_t lang, uint32 seed);
 char *GetTownName(char *buff, const TownNameParams *par, uint32 townnameparts, const char *last);
 char *GetTownName(char *buff, const Town *t, const char *last);
-bool VerifyTownName(uint32 r, const TownNameParams *par, TownNames *town_names = NULL);
-bool GenerateTownName(uint32 *townnameparts, TownNames *town_names = NULL);
+bool VerifyTownName(uint32 r, const TownNameParams *par, TownNames *town_names = nullptr);
+bool GenerateTownName(uint32 *townnameparts, TownNames *town_names = nullptr);
 
 #endif /* TOWNNAME_FUNC_H */
