@@ -16,7 +16,7 @@
 #include "tile_type.h"
 
 /** Vehicle List type flags */
-enum VehicleListType {
+enum VehicleListType : byte {
 	VL_STANDARD,
 	VL_SHARED_ORDERS,
 	VL_STATION_LIST,
@@ -36,6 +36,8 @@ struct VehicleListIdentifier {
 	bool UnpackIfValid(uint32 data);
 	static VehicleListIdentifier UnPack(uint32 data);
 
+	bool Valid() const { return this->type < VLT_END; }
+
 	/**
 	 * Create a simple vehicle list.
 	 * @param type    List type.
